pub enum SharedStateError<StorageError = Infallible> {
WrongState(WrongStateError),
Storage(StorageError),
}Expand description
Failure to acquire a typed view of shared state.
Variants
WrongState(WrongStateError)
The container was borrowed successfully, but the committed state did not match.
Storage(StorageError)
The backing storage could not be borrowed or locked.