ConcreteStateKind

Struct ConcreteStateKind 

pub struct ConcreteStateKind;
Marker kind for concrete state ZSTs.

This is the kind assigned by States!. Concrete states can be stored as the authoritative state in shared storage and can appear as concrete transition sources or targets.