SPinMut

Trait SPinMut 

pub trait SPinMut: SPinRef + MayTransition {
    // Required method
    fn s_pin_mut<T, State>(inner: &mut Self::Inner<T, State>) -> Pin<&mut T>
       where T: StateMachineImpl;
}
Storage backend that can expose a pinned mutable runtime reference.

This is the capability required by pinned transition effects. It does not imply SMut: a backend may safely provide Pin<&mut T> for !Unpin values while still refusing to provide &mut T.

Required Methods

fn s_pin_mut<T, State>(inner: &mut Self::Inner<T, State>) -> Pin<&mut T>

Mutably borrows the runtime implementation as a pinned reference.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl SPinMut for StorageStateOwnedPinBox

Available on crate feature alloc only.