RuntimeStateMarker

Type Alias RuntimeStateMarker 

pub type RuntimeStateMarker<Marker> = <<Marker as StateMarker>::Kind as StateKind>::RuntimeState<Marker>;
Runtime marker used when borrowing Marker from shared storage.

For concrete states this is Marker. For union markers this is the generated joint [StateUnionState<Marker>].

This alias is mostly visible in shared-storage return types. For example, shared.borrow::<Connected>() returns an immutable State<StorageStateRef<...>, T, Connected> view, while shared.borrow::<Online>() returns an immutable State<StorageStateRef<...>, T, StateUnionState<Online>> view.