SMutex

Type Alias SMutex 

pub type SMutex<'a> = StorageStateMut<'a, MutexStorage>;
Mutable-guard storage backend for MutexStorage.

This is the concrete guard storage used by SArcMutex::borrow_mut. Prefer a generic S: SMut bound unless you intentionally need to restrict a function to mutex-backed shared state.

Aliased Type

pub struct SMutex<'a>(/* private fields */);