SPin

Type Alias SPin 

pub type SPin<T, S> = StateOwned<Pin<T>, S>;
Owned state whose runtime value is pinned by an arbitrary pinning pointer.

This is the direct owned alias for StateOwned<Pin<P>, S>. In generic state-machine methods prefer State plus a storage backend such as SPinBox, because that keeps the same method usable for owned, boxed, pinned, and guard-backed states.

Aliased Type

pub struct SPin<T, S> { /* private fields */ }