pub type WeakSArcRwLock<T> = WeakSArc<RwLockStorage, T>;Expand description
Weak handle for SArcRwLock.
Use this alias when the strong handle has type SArcRwLock<T>.
Aliased Type
pub struct WeakSArcRwLock<T> { /* private fields */ }pub type WeakSArcRwLock<T> = WeakSArc<RwLockStorage, T>;Weak handle for SArcRwLock.
Use this alias when the strong handle has type SArcRwLock<T>.
pub struct WeakSArcRwLock<T> { /* private fields */ }