pub type WeakSRcRefCell<T> = WeakSRc<RefCellStorage, T>;Expand description
Weak handle for SRcRefCell.
Use this alias when the strong handle has type SRcRefCell<T>.
Aliased Type
pub struct WeakSRcRefCell<T> { /* private fields */ }pub type WeakSRcRefCell<T> = WeakSRc<RefCellStorage, T>;Weak handle for SRcRefCell.
Use this alias when the strong handle has type SRcRefCell<T>.
pub struct WeakSRcRefCell<T> { /* private fields */ }