pub type SBox<T, S> = State<StorageStateOwnedBox, T, S>;Expand description
Owned state whose runtime value is stored in Box<T>.
This is only a type alias for State<StorageStateOwnedBox, T, S>. Create it
from an already-owned state with SBox::new(State<StorageStateOwnedBox, T, S>::new)
so the current state is preserved while changing containers:
ⓘ
let owned: State<SOwned, Connection, Disconnected> = State::new(connection);
let boxed: SBox<Connection, Disconnected> = SBox::new(owned);Aliased Type
pub struct SBox<T, S> { /* private fields */ }