pub type SRefCell<'a> = StorageStateMut<'a, RefCellStorage>;Expand description
Mutable-guard storage backend for RefCellStorage.
This is the Storage parameter of a state returned by
SRcRefCell::borrow_mut. It is useful in signatures when a method wants
to specifically accept a RefCell guard rather than any crate::SMut
storage:
ⓘ
fn only_ref_cell_guard(
state: magicstatemachines::State<
magicstatemachines::SRefCell<'_>,
Connection,
Connected,
>,
) {
drop(state);
}State-machine implementation methods usually prefer S: SMut so they also
work with owned, boxed, mutex, and custom storage.
Aliased Type
pub struct SRefCell<'a>(/* private fields */);