pub type SRwLock<'a> = StorageStateMut<'a, RwLockStorage>;Expand description
Mutable-guard storage backend for RwLockStorage.
This is the concrete guard storage used by SArcRwLock::borrow_mut.
It represents an active write guard whose final typestate will be committed
back to the RwLock when the returned State is dropped.
Aliased Type
pub struct SRwLock<'a>(/* private fields */);